export class Main extends Indicator {

    constructor() {
        super();

        this.setProperty(Property.SeparateWindow, true);

        this.addInput("pq", InputType.int, 2);
        this.addInput("pr", InputType.int, 10);
        this.addInput("ps", InputType.int, 5);
        this.addInput("trigger", InputType.int, 3);
        this.addInput("PriceType", InputType.PriceType, PriceType.Bid);

        this.buffers = {
            ErgoCCI : this.addBuffer(),
            MainCCI : this.addBuffer()
        };

        this.arr = {
            mtm : [],
            absmtm : [],
            var1 : [],
            var2 : [],
            var2a : [],
            var2b : []
        };

        this.vars = {
            signal: 0,
        }
    }

    onInit() {
        this.buffers.ErgoCCI
            .setShape(Shape.Line)
            .setColor(Color.Blue)
            .setWidth(2)
            .setLabel('Egodic CCI')
        ;

        this.buffers.MainCCI
            .setShape(Shape.Line)
            .setColor(Color.Red)
            .setLabel('Trigger Line')
        ;
    }

    async onUpdate() {
        const {ErgoCCI, MainCCI} = this.buffers,
            {pq, pr, ps, trigger, PriceType} = this.getInputs(),
            {mtm, absmtm, var1, var2, var2a, var2b} = this.arr,
            {Close} = await Bar.load([Bar.Mode.Close], PriceType),
            barSize = Close.length;

        let limit, i, counted_bars = Bar.counted(), list, list2,
            {signal} = this.vars;

        if (counted_bars < 0) return (-1);
        if (counted_bars > 0) counted_bars--;
        limit = barSize - counted_bars;
        for (i = 0; i <= barSize; i++) {
            mtm[i] = Close[i] - Close[i + 1];
        }

        for (i = 0; i <= barSize - 1; i++) {
            absmtm[i] = Math.abs(mtm[i]);
        }
        list = Indicators.MAOnArray(mtm, 0, pq, 0, Averaging.Exponential);
        for (i = 0; i <= barSize - 1; i++) {
            var1[i] = list[i];
        }

        list = Indicators.MAOnArray(var1, barSize, pr, 0, Averaging.Exponential);
        for (i = 0; i <= barSize - 1; i++) {
            var2[i] = list[i];
        }
        list = Indicators.MAOnArray(absmtm, 0, pq, 0, Averaging.Exponential);
        for (i = 0; i <= barSize - 1; i++) {
            var2a[i] = list[i];
        }
        list = Indicators.MAOnArray(var2a, 0, pr, 0, Averaging.Exponential);
        for (i = 0; i <= barSize - 1; i++) {
            var2b[i] = list[i];
        }
        list = Indicators.MAOnArray(var2, 0, ps, 0, Averaging.Exponential);
        list2 = Indicators.MAOnArray(var2b, 0, ps, 0, Averaging.Exponential);
        for (i = 0; i <= barSize - 1; i++) {
            ErgoCCI.set(i, (500 * list[i]) / list2[i]);
        }
        list = Indicators.MAOnArray(ErgoCCI, 0, trigger, 0, Averaging.Exponential);
        for (i = 0; i <= barSize; i++) {
            MainCCI.set(i, list[i]);
        }

        for (i = 0; i <= barSize; i++) {
            if (MainCCI.get(i) > ErgoCCI.get(i)) {
                signal = "SHORT";
            }
            if (MainCCI.get(i) < ErgoCCI.get(i)) {
                signal = "LONG";
            }
            if (MainCCI.get(i) === ErgoCCI.get(i)) {
                signal = "NEUTRAL";
            }

            ErgoCCI.setShortName("FX Sniper's Ergodic CCI: " + signal);
            MainCCI.setShortName("FX Sniper's Ergodic CCI: " + signal);
        }
    }
}
